summary refs log tree commit diff
diff options
context:
space:
mode:
authorPhilipp Hagemeister <phihag@phihag.de>2014-03-22 14:20:05 +0100
committerPhilipp Hagemeister <phihag@phihag.de>2014-03-22 14:20:07 +0100
commita9c2896e2252839c2e4801189f10acce7ff6413e (patch)
treec466c3f8056e0c69ab3caa74e97e15745be076dd
parentfa154d1dbe3c8dec53c227e3c19b586516e17c43 (diff)
downloadyoutube-dl-a9c2896e2252839c2e4801189f10acce7ff6413e.tar.gz
youtube-dl-a9c2896e2252839c2e4801189f10acce7ff6413e.tar.xz
youtube-dl-a9c2896e2252839c2e4801189f10acce7ff6413e.zip
Make missing test definition fields an error
If the result is not testable (for example, because a description changes often), either pass in a type or a regular expression (a string starting with 're:')
-rw-r--r--test/test_download.py9
-rw-r--r--youtube_dl/extractor/arte.py1
2 files changed, 8 insertions, 2 deletions
diff --git a/youtube_dl/extractor/arte.py b/youtube_dl/extractor/arte.py
index 548442166..979481b21 100644
--- a/youtube_dl/extractor/arte.py
+++ b/youtube_dl/extractor/arte.py
@@ -302,5 +302,6 @@ class ArteTVConcertIE(ArteTVPlus7IE):
             'ext': 'mp4',
             'title': 'The Notwist im Pariser Konzertclub "Divan du Monde"',
             'upload_date': '20140128',
+            'description': 'md5:486eb08f991552ade77439fe6d82c305',
         },
     }
diff --git a/test/test_download.py b/test/test_download.py
index 8fccdaf9e..815f5bb09 100644
--- a/test/test_download.py
+++ b/test/test_download.py
@@ -163,12 +163,17 @@ def generator(test_case):
                 for key in ['webpage_url', 'extractor', 'extractor_key']:
                     self.assertTrue(info_dict.get(key), u'Missing field: %s' % key)
 
                 # If checkable fields are missing from the test case, print the info_dict
                 test_info_dict = dict((key, value if not isinstance(value, compat_str) or len(value) < 250 else 'md5:' + md5(value))
                     for key, value in info_dict.items()
                     if value and key in ('title', 'description', 'uploader', 'upload_date', 'timestamp', 'uploader_id', 'location'))
-                if not all(key in tc.get('info_dict', {}).keys() for key in test_info_dict.keys()):
+                missing_keys = set(test_info_dict.keys()) - set(tc.get('info_dict', {}).keys())
+                if missing_keys:
                     sys.stderr.write(u'\n"info_dict": ' + json.dumps(test_info_dict, ensure_ascii=False, indent=4) + u'\n')
+                    self.assertFalse(
+                        missing_keys,
+                        'Missing keys in test definition: %s' % (
+                            ','.join(sorted(missing_keys))))
         finally:
             try_rm_tcs_files()
 
@@ -163,12 +163,17 @@ def generator(test_case):
                     self.assertTrue(info_dict.get(key), u'Missing field: %s' % key)
 
-                # If checkable fields are missing from the test case, print the info_dict
+                # Are checkable fields missing from the test case definition?
                 test_info_dict = dict((key, value if not isinstance(value, compat_str) or len(value) < 250 else 'md5:' + md5(value))
                     for key, value in info_dict.items()